@@ -2,8 +2,6 @@
 from enum import IntEnum
 from typing import Any, Dict
 
-from kameleoon.network.post_body_line import PostBodyLine, get_nonce
-
 
 class DataType(IntEnum):
     """Data types"""
@@ -13,23 +11,22 @@ class DataType(IntEnum):
     CONVERSION = 2
     DEVICE = 3
     PAGE_VIEW = 4
+    USER_AGENT = 5
+    ASSIGNED_VARIATION = 6
 
 
-class Data(PostBodyLine):
+class BaseData:
     """Base data class"""
 
-    def __init__(self) -> None:
-        super().__init__()
-        self._nonce: str = get_nonce()
-        self.sent: bool = False
+    @property
+    def data_type(self) -> DataType:
+        """Returns data type of the instance"""
+        raise NotImplementedError
 
     def to_dict(self) -> Dict[str, Any]:
         """Convert class instance to dict"""
         return self.__dict__
 
-    def obtain_full_post_text_line(self) -> str:
-        """
-        obtain full post text line
-        :return:
-        """
-        raise NotImplementedError
+
+class Data(BaseData):  # pylint: disable=W0223
+    """Base external data class"""
