@@ -3,10 +3,11 @@
 import json
 from typing import List, Optional
 from kameleoon.data.data import Data, DataType
+from kameleoon.network.sendable import DuplicationSafeSendableBase
 from kameleoon.network.query_builder import QueryBuilder, QueryParam, QueryParams
 
 
-class PageView(Data):
+class PageView(Data, DuplicationSafeSendableBase):
     """Page view"""
 
     EVENT_TYPE = "page"
@@ -27,19 +28,38 @@ class PageView(Data):
                 kameleoon_client.add_data(visitor_code, PageView("www.test.com", "test-title"))
         """
         super().__init__()
-        self.url = url
-        self.title = title
-        self.referrers = referrers
-        self._instance: DataType = DataType.PAGE_VIEW
+        self.__url = url
+        self.__title = title
+        self.__referrers = referrers
 
-    def obtain_full_post_text_line(self) -> str:
-        qb = QueryBuilder(  # pylint: disable=C0103
+    @property
+    def url(self) -> str:
+        """Returns URL"""
+        return self.__url
+
+    @property
+    def title(self) -> str:
+        """Returns title"""
+        return self.__title
+
+    @property
+    def referrers(self) -> Optional[List[int]]:
+        """Returns referrer list"""
+        return self.__referrers
+
+    @property
+    def data_type(self) -> DataType:
+        return DataType.PAGE_VIEW
+
+    def encode_query(self) -> str:
+        return super().encode_query() if len(self.__url) > 0 else ""
+
+    def _add_query_params(self, qb: QueryBuilder) -> None:
+        qb.extend(
             QueryParam(QueryParams.EVENT_TYPE, self.EVENT_TYPE),
             QueryParam(QueryParams.HREF, self.url),
             QueryParam(QueryParams.TITLE, self.title),
-            QueryParam(QueryParams.NONCE, self._nonce),
         )
         if self.referrers:
             str_referrers = json.dumps(self.referrers, separators=(",", ":"))
             qb.append(QueryParam(QueryParams.REFERRERS_INDICES, str_referrers))
-        return str(qb)
